# Ads Data Hub API client for Python

[![pypi package](https://badge.fury.io/py/adsdatahub.svg)](https://pypi.org/project/adsdatahub)

## Usage

Please refer to the [examples](https://github.com/ya7010/adsdatahub-py/tree/main/adsdatahub/examples).
